@@ -32,11 +32,14 @@ class TranscriptionRequest:
                  enable_numerals_conversion: bool = False,
                  speakers_diarization: bool = False,
                  speakers_number: Optional[int] = None,
+                 multi_channels: bool = False,
                  **kwargs):
         assert file_uid is not None
         assert file_path is not None
         assert model is not None
         assert transcript_format is not None
+        assert not speakers_diarization or not multi_channels, 'Speakers diarization and multi-channels cannot' \
+                                                               ' be simultaneously enabled'
 
         self.uid = str(uuid.uuid4())
         self.file_uid: str = file_uid
@@ -54,6 +57,7 @@ class TranscriptionRequest:
         self.enable_numerals_conversion: bool = enable_numerals_conversion
         self.speakers_diarization: bool = speakers_diarization
         self.speakers_number: Optional[int] = speakers_number
+        self.multi_channels: bool = multi_channels
 
         if isinstance(hotwords, list):
             self.hotwords = hotwords
